/*
Copyright (c) 1998-2009 VIA Technologies, Inc. All Rights Reserved.
 
This PROPRIETARY SOURCE CODE contains proprietary information of VIA 
Technologies, Inc. (VIA); Contents of this file shall not be disclosed to any 3rd party, 
copied or duplicated in any form, in whole or in part without prior written consent of 
VIA.  THIS SOURCE CODE & ANY RELATED DOCUMENTATION 
(COLLECTIVELY SOFTWARE) ARE PROVIDED AS IS, WITH ALL FAULTS, & 
WITHOUT WARRANTY OF ANY KIND.  VIA DISCLAIMS ALL EXPRESS OR 
IMPLIED WARRANTIES.  USER ACKNOWLEDGES THAT PARTIES FOR ANY 
DAMAGES ARISING FROM USE OF SOFTWARE OR ITS DERIVATIVE, 
INCLUDING, W/O LIMITATION, LOSS OF USE, DATA OR PROFITS. USER
WHOLLY ASSUMES ALL RISK ARISING FROM USE & PERFORMANCE OF 
SOFTWARE
*/ 
 
#ifndef ETKAPI_HWM_H_
#define ETKAPI_HWM_H_

#include "etkapi_base.h"

#ifdef __cplusplus
extern "C" {
#endif

/************************************************************************
		Hardware Monitor Information
************************************************************************/

/**
 * The board supports hardware monitor function or not
 * @return   : Returns TRUE if support or FALSE otherwise.
 */
SMARTETK_API BOOL ETKSdk_SupportHardwareMonitor(void);

/**
 * Get the fan speed of CPU.
 * @param pdwFanSpeed: a pointer to a variable that receives the fan speed of CPU.
 * @return   :
 * ETK_S_OK: The function is success.
 * ETK_E_INVALID_ARG: if pdwFanSpeed is NULL.
 * ETK_E_BOARD_NOT_SUPPORT: The board is not supported.
 * ETK_E_HARDWARE_ERROR: Hardware error.
 */
SMARTETK_API DWORD ETKHwmCpu_GetFanSpeed(DWORD* pdwFanSpeed);
/**
 * Get the temperature of CPU.
 * For dual-core or quad-core cpu, only support getting the temperature of the cpu core 
 * on which your SmartETK application runs.
 * We don't support getting the temperatures of all the cpu cores.
 * @param pTemperature: a pointer to a variable that receives the temperature of CPU.
 * @return   :
 * ETK_S_OK: The function is success.
 * ETK_E_INVALID_ARG: if pTemperature is NULL.
 * ETK_E_FUNC_NOT_SUPPORT: The function is not supported on this board.
 * ETK_E_HARDWARE_ERROR: Hardware error.
 */
SMARTETK_API DWORD ETKHwmCpu_GetTemperature(double* pTemperature);
/**
 * Get the fan speed of system.
 * @param pdwFanSpeed: a pointer to a variable that receives the fan speed of system.
 * @return   :
 * ETK_S_OK: The function is success.
 * ETK_E_INVALID_ARG: pdwFanSpeed is NULL.
 * ETK_E_FUNC_NOT_SUPPORT: The function is not supported on this board.
 * ETK_E_HARDWARE_ERROR: Hardware error.
 */
SMARTETK_API DWORD ETKHwmSystem_GetFanSpeed(DWORD* pdwFanSpeed);
/**
 * Get the temperature of system.
 * @param pTemperature: a pointer to a variable that receives the temperature of system.
 * @return   :
 * ETK_S_OK: The function is success.
 * ETK_E_INVALID_ARG: pTemperature is NULL.
 * ETK_E_FUNC_NOT_SUPPORT: The function is not supported on this board.
 * ETK_E_HARDWARE_ERROR: Hardware error.
 */
SMARTETK_API DWORD ETKHwmSystem_GetTemperature(double* pTemperature);

/// it is voltage of CPU core on the board.
#define ETK_VOLT_VCORE        (1<<0)
/// it is CMOS battery voltage on the board.
#define ETK_VOLT_VBAT         (1<<1)
/// it is voltage of standby on the board.
#define ETK_VOLT_VSB          (1<<2)
/// it is 3.3V on the board.
#define ETK_VOLT_33V          (1<<3)
/// it is 5V on the board.
#define ETK_VOLT_50V          (1<<4)
/// it is 12V on the board.
#define ETK_VOLT_120V         (1<<5)
/// it is -12V on the board.
#define ETK_VOLT_N120V        (1<<6)
/// max voltage types
#define ETK_VOLT_MAX_LIMIT    7
/**
 * @def ETK_VOLT_ALL
 * @brief  all of voltages.
 */
#define ETK_VOLT_ALL          ((1<<ETK_VOLT_MAX_LIMIT)-1)

/**
 * Get one of voltage value from voltage sensors.
 * @param dwVoltageType: There are seven kind of voltage.
 * ETK_VOLT_VCORE = 1, is voltage of CPU core on the board.
 * ETK_VOLT_VBAT = 2, is CMOS battery voltage on the board.
 * ETK_VOLT_VSB = 4, is voltage of standby on the board.
 * ETK_VOLT_33V = 8, is 3.3V on the board.
 * ETK_VOLT_50V = 16, is 5V on the board.
 * ETK_VOLT_120V = 32, is +12V on the board.
 * ETK_VOLT_N120V = 64, is -12V on the board.
 * @param pVoltage: a pointer to a variable that receives the voltage from voltage sensors.
 * @return   :
 * ETK_S_OK: The function is success.
 * ETK_E_INVALID_ARG: if pVoltage is NULL.
 * ETK_E_FUNC_NOT_SUPPORT: The function is not supported on this board.
 * ETK_E_HARDWARE_ERROR: Hardware error.
 */
SMARTETK_API DWORD ETKHwmVoltage_Get(DWORD dwVoltageType, double* pVoltage);


#ifdef __cplusplus
} // extern C
#endif

#endif
